require 'ostruct'

module AudioFeedManager
  describe AudioFileAdder do
    let(:feed) { build_feed }
    let(:saved_audio_file) { AudioFile.new(id: 'audio_files/saved') }

    fake(:id3_tags)
    fake(:feed_items_repository)
    let(:audio_file_repository) { fake(:audio_file_repository, add: saved_audio_file) }

    let(:audio_file_adder) { isolate(AudioFileAdder) }

    it "adds the file based on ID3 tags to the specified feed" do
      stub(id3_tags).read("/some/file") { Tags.new(title: "Some Audio File", artist: "Some Author") }
      audio_file = AudioFile.new(title: "Some Audio File", author: "Some Author")

      audio_file_adder.call(feed, "/some/file")

      expect(audio_file_repository).to have_received.add(audio_file, "/some/file")
    end

    it "adds the audio file to the specified feed" do
      stub(id3_tags).read("/some/file") { Tags.new(title: "Some Audio File", artist: "Some Author") }

      audio_file_adder.call(feed, "/some/file")

      expect(feed_items_repository).to have_received.add(feed, saved_audio_file)
    end

    it "fetches title from the lambda if no title discovered" do
      stub(id3_tags).read("/some/file") { Tags.new(artist: "Some Author") }
      audio_file = AudioFile.new(title: "some title", author: "Some Author")

      audio_file_adder.call(feed, "/some/file", title: ->() { "some title" })

      expect(audio_file_repository).to have_received.add(audio_file, "/some/file")
    end

    it "fetches author from the lambda if no author discovered" do
      stub(id3_tags).read("/some/file") { Tags.new(title: "Some Audio File") }
      audio_file = AudioFile.new(title: "Some Audio File", author: "some author")

      audio_file_adder.call(feed, "/some/file", author: ->() { "some author" })

      expect(audio_file_repository).to have_received.add(audio_file, "/some/file")
    end
  end
end
