module AudioFeedManager
  describe AudioFileRepository do
    let(:audio_file) { AudioFile.new(title: "hello", author: "test") }
    let(:saved_audio_file) { AudioFile.new(id: "audio_files/foo", secret_token: "abcd", extension: ".mp3") }

    let(:audio_files_prefix) { "audio_files" }
    let(:audio_files_directory) { "/tmp/foo/audio_files" }
    let(:data_files_directory) { Pathname.new("/tmp/foo/data") }
    let(:new_model_creator) { fake(:new_model_creator, create: saved_audio_file) }
    fake(:storage)

    let(:audio_file_repository) { isolate(AudioFileRepository) }

    before do
      FileUtils.rm_rf("/tmp/foo/data")
      FileUtils.mkdir_p("/tmp/foo/data")
    end

    it "saves the metadata while generating a secret token and ID" do
      audio_file_repository.add(audio_file, fixture_file("test.mp3"))

      expect(new_model_creator).to have_received.create(audio_file, prefix: "audio_files", directory: "/tmp/foo/audio_files")
    end

    it "saves the file extension" do
      modified_audio_file = AudioFile.new(title: audio_file.title,
                                          author: audio_file.author,
                                          extension: ".mp3",
                                          size: 11305,
                                          content_type: "audio/mpeg")
      audio_file_repository.add(audio_file, fixture_file("test.mp3"))

      expect(new_model_creator).to have_received.create(modified_audio_file, prefix: "audio_files", directory: "/tmp/foo/audio_files")
    end

    it "copies the given file to a location based on the secret token" do
      audio_file_repository.add(audio_file, fixture_file("test.mp3"))

      expect(File.exist?("/tmp/foo/data/abcd.mp3")).to be(true)
    end

    it "fetches the audio files" do
      stub(storage).read("audio_files/foo") { {id: "audio_files/foo", title: "Foo"} }

      audio_file = audio_file_repository.fetch("audio_files/foo")

      expect(audio_file).to eq(AudioFile.new(id: "audio_files/foo", title: "Foo"))
    end

    it "raises an error if audio file was not found" do
      stub(storage).read("audio_files/foo") { raise FileNotFound }

      expect{
        audio_file_repository.fetch("audio_files/foo")
      }.to raise_error(AudioFileNotFound)
    end
  end
end
