module AudioFeedManager
  describe AddAudioFile do
    let(:feed) { build_feed }
    let(:directory) { Pathname.new('/tmp/foo') }
    fake(:feed_repository)
    fake(:audio_file_adder)
    fake(:console)
    fake(:rss_generator)

    let(:add_audio_file) { isolate(AddAudioFile) }

    it "adds the audio file to the feed" do
      stub(feed_repository).fetch("feeds/some-id") { feed }

      add_audio_file.run(feed: "feeds/some-id", files: ["file"])

      expect(audio_file_adder).to have_received.call(feed, Pathname.new("/tmp/foo/file"), title: any(Proc), author: any(Proc))
    end

    it "prints an error message when the feed was not found" do
      stub(feed_repository).fetch("feeds/some-id") { raise FeedNotFound }

      add_audio_file.run(feed: "feeds/some-id", files: ["/some/file"])

      expect(console).to have_received.die(any_args)
    end

    it "prints an error message when the file was not found" do
      stub(feed_repository).fetch("feeds/some-id") { raise Errno::ENOENT }

      add_audio_file.run(feed: "feeds/some-id", files: ["/some/file"])

      expect(console).to have_received.die(any_args)
    end

    it "generates rss after adding the file" do
      stub(feed_repository).fetch("feeds/some-id") { feed }

      add_audio_file.run(feed: "feeds/some-id", files: ["file"])

      expect(rss_generator).to have_received.generate(feed)
    end
  end
end
