module AudioFeedManager
  describe AddFeed do
    fake(:console)
    fake(:feed_repository)
    fake(:rss_generator)

    let(:add_feed) { isolate(AddFeed) }
    let(:feed) { Feed.new(id: "feeds/hello-world")  }

    before do
      stub(console).ask("Description", default: "Hello World!") { "some description" }
      stub(feed_repository).add(any_args) { feed }
    end

    it "adds the feed with the given title" do
      add_feed.run(title: "Hello World!")

      expect(feed_repository).to have_received.add(Feed.new(title: "Hello World!", description: "some description"))
    end

    it "generates an RSS file for the created feed" do
      add_feed.run(title: "Hello World!")

      expect(rss_generator).to have_received.generate(feed)
    end
  end
end
