module AudioFeedManager
  describe ArgumentsSpecification do
    describe "#usage_line" do
      it "returns the command name" do
        specification = ArgumentsSpecification.specify do |s|
          s.name "foo"
        end

        expect(specification.usage_line).to eq("foo")
      end

      it "returns the command name and required arguments" do
        specification = ArgumentsSpecification.specify do |s|
          s.name "foo"
          s.argument :some_arg, required: true
        end

        expect(specification.usage_line).to eq("foo <SOME_ARG>")
      end

      it "returns the command name and optional arguments" do
        specification = ArgumentsSpecification.specify do |s|
          s.name "foo"
          s.argument :some_arg, required: false
        end

        expect(specification.usage_line).to eq("foo [SOME_ARG]")
      end

      it "returns the command name and varargs" do
        specification = ArgumentsSpecification.specify do |s|
          s.name "foo"
          s.varargs :songs
        end

        expect(specification.usage_line).to eq("foo [SONGS...]")
      end

      it "returns the command name and a combination of optional, required arguments and varargs" do
        specification = ArgumentsSpecification.specify do |s|
          s.name "foo"
          s.argument :first_arg, required: true
          s.argument :second_arg, required: false
          s.varargs :rest
        end

        expect(specification.usage_line).to eq("foo <FIRST_ARG> [SECOND_ARG] [REST...]")
      end
    end
  end
end
