module AudioFeedManager
  describe CommandsList do
    fake(:initialize_project)
    fake(:add_feed)
    fake(:list_feeds)
    fake(:add_audio_file)
    fake(:show_feed)
    fake(:get_feed_url)
    fake(:update_feed_rss)
    fake(:publish)
    fake(:console)

    let(:commands_list) { isolate(CommandsList) }

    it "returns the initialize_project command for 'init'" do
      command, opts = commands_list.get(["init", "foo"])

      expect(command).to be(initialize_project)
      expect(opts).to eq(["foo"])
    end

    it "returns help when called with no arguments" do
      command, opts = commands_list.get([])

      expect(command).to be(commands_list)
      expect(opts).to eq([])
    end

    it "returns help when called with 'help'" do
      command, opts = commands_list.get(["help"])

      expect(command).to be(commands_list)
      expect(opts).to eq([])
    end

    it "returns add_feed command for 'feeds add'" do
      command, opts = commands_list.get(["feeds", "add", "foo"])

      expect(command).to be(add_feed)
      expect(opts).to eq(["foo"])
    end

    it "returns show_feed for 'feeds show'" do
      command, opts = commands_list.get(["feeds", "show", "feeds/hello"])

      expect(command).to be(show_feed)
      expect(opts).to eq(["feeds/hello"])
    end

    it "returns get_feed_url for 'feeds get-url'" do
      command, opts = commands_list.get(["feeds", "get-url", "feeds/hello"])

      expect(command).to be(get_feed_url)
      expect(opts).to eq(["feeds/hello"])
    end

    it "returns update_feed_rss for 'feeds update-rss'" do
      command, opts = commands_list.get(["feeds", "update-rss", "feeds/hello"])

      expect(command).to be(update_feed_rss)
      expect(opts).to eq(["feeds/hello"])
    end

    it "returns add_audio_file for 'audio add'" do
      command, opts = commands_list.get(["audio", "add", "feeds/hello", "/some/file.mp3"])

      expect(command).to be(add_audio_file)
      expect(opts).to eq(["feeds/hello", "/some/file.mp3"])
    end

    it "returns list_feeds command for 'feeds list'" do
      command, opts = commands_list.get(["feeds", "list"])

      expect(command).to be(list_feeds)
      expect(opts).to eq([])
    end

    it "returns publish command for 'publish'" do
      command, opts = commands_list.get(["publish"])

      expect(command).to be(publish)
      expect(opts).to eq([])
    end

    it "raises an UnknownCommand error for other commands" do
      expect {
        commands_list.get("asdf")
      }.to raise_error(UnknownCommand)
    end
  end
end
