module AudioFeedManager
  describe GetFeedUrl do
    fake(:feed_repository)
    let(:console) { FakeConsole.new }
    fake(:url_maker, feed_url: "http://example.com/feed")

    let(:get_feed_url) { isolate(GetFeedUrl) }

    it "prints the feed url" do
      feed = build_feed
      stub(feed_repository).fetch("feeds/foo") { feed }

      get_feed_url.run(feed: "feeds/foo")

      expect(console.out).to eq("http://example.com/feed\n")
    end

    it "returns a friendly message when feed not found" do
      stub(feed_repository).fetch("feeds/foo") { raise FeedNotFound.for_id("feeds/foo") }

      get_feed_url.run(feed: "feeds/foo")

      expect(console.out).to include("not found")
    end
  end
end
