module AudioFeedManager
  describe ShowFeed do
    let(:feed) { Feed.new(id: "feeds/hello", title: "Hello!") }
    fake(:feed_repository)
    fake(:feed_items_repository, list: [])
    fake(:url_maker, feed_url: "http://example.com/feeds/abc.xml")
    let(:console) { FakeConsole.new }

    let(:show_feed) { isolate(ShowFeed) }

    it "returns detailes information about the feed" do
      stub(feed_repository).fetch("feeds/foo") { feed }
      audio_file = AudioFile.new(id: "audio_files/bar", title: "Some audio file")
      stub(feed_items_repository).list(feed) { [audio_file] }

      show_feed.run(feed: "feeds/foo")

      expect(console.out).to (include("Hello!"))
      expect(console.out).to (include("http://example.com/feeds/abc.xml"))
      expect(console.out).to (include("Some audio file"))
    end

    it "prints a helpful message when feed was not found" do
      stub(feed_repository).fetch("feeds/foo") { raise FeedNotFound.for_id("feeds/foo") }

      show_feed.run(feed: "feeds/foo")

      expect(console.out).to (include("not found"))
    end

    it "prints a helpful message when there are no audio files" do
      stub(feed_repository).fetch("feeds/foo") { feed }
      stub(feed_items_repository).list(feed) { [] }

      show_feed.run(feed: "feeds/foo")

      expect(console.out).to (include("No audio files"))
    end
  end
end

