module AudioFeedManager
  describe CLI do
    fake(:command, arguments: ArgumentsSpecification.new, name: "init") { InitializeProject }
    fake(:commands_list)
    fake(:arguments_parser)
    fake(:help)
    fake(:console)
    let(:arguments) { Arguments.from_hash(project_dir: "my-project-name") }

    let(:cli) { isolate(CLI) }

    it "runs the specified command" do
      stub(commands_list).get(["init", "my-project-name"]) { [command, ["my-project-name"]]}
      stub(arguments_parser).parse(command.arguments, ["my-project-name"]) { arguments }

      cli.run(["init", "my-project-name"])

      expect(command).to have_received.run(project_dir: "my-project-name")
    end

    it "prints command usage if command arguments are invalid and stops the application" do
      stub(commands_list).get(["init"]) { [command, []]}
      stub(arguments_parser).parse(command.arguments, []) { raise InvalidArguments }

      expect {
        cli.run(["init"])
      }.to raise_error(StopApplication)

      expect(help).to have_received.print_command_usage("init")
    end

    it "prints usage if command is invalid and stops the application" do
      stub(commands_list).get(["foo"]) { raise UnknownCommand }

      expect {
        cli.run(["foo"])
      }.to raise_error(StopApplication)

      expect(help).to have_received.print_usage
    end
  end
end
