module AudioFeedManager
  describe FeedItemsRepository do
    let(:items_directory) { Pathname.new("/tmp/foo") }
    let(:feed_items_repository) { isolate(FeedItemsRepository) }
    fake(:audio_file_repository)

    before do
      FileUtils.rm_rf(items_directory)
      FileUtils.mkdir_p(items_directory)
    end

    it "returns an empty array for a feed with no items" do
      feed = build_feed

      expect(feed_items_repository.list(feed)).to eq([])
    end

    it "returns a list of audio files added for a feed, latest first" do
      feed = build_feed(id: "feeds/abc")
      other_feed = build_feed(id: "feeds/def")
      foo = AudioFile.new(id: "audio_files/foo")
      bar = AudioFile.new(id: "audio_files/bar")
      baz = AudioFile.new(id: "audio_files/baz")
      stub(audio_file_repository).fetch("audio_files/foo") { foo }
      stub(audio_file_repository).fetch("audio_files/bar") { bar }
      stub(audio_file_repository).fetch("audio_files/baz") { baz }
      feed_items_repository.add(feed, foo)
      feed_items_repository.add(feed, bar)
      feed_items_repository.add(other_feed, baz)

      expect(feed_items_repository.list(feed)).to eq([bar, foo])
    end
  end
end
