require 'spec_helper'

module AudioFeedManager
  describe FeedRepository do
    let(:feed_repository) { isolate(FeedRepository) }
    let(:feeds_directory) { Pathname.new("/tmp/foo/feeds") }
    let(:feeds_prefix) { "feeds" }
    fake(:new_model_creator)
    fake(:storage)
    fake(:directory_lister)

    it "stores new feeds" do
      saved_feed = Feed.new(id: "feeds/foo")
      feed = Feed.new(title: "Hello World!")
      mock(new_model_creator).create(feed, directory: feeds_directory,
                                           prefix: feeds_prefix) { saved_feed }

      feed = feed_repository.add(feed)
    end

    it "fetches the stored feeds" do
      stub(storage).read("feeds/hello-world") { {id: "feeds/hello-world", title: "Hello World"} }

      expect(feed_repository.fetch("feeds/hello-world")).to eq(Feed.new(id: "feeds/hello-world", title: "Hello World"))
    end

    it "raises FeedNotFound when a feed by given id does not exist" do
      stub(storage).read("feeds/hello-world") { raise FileNotFound }

      expect{feed_repository.fetch("feeds/hello-world")}.to raise_error(FeedNotFound)
    end

    it "lists the feeds" do
      stub(directory_lister).list(feeds_directory) { ["hello-world"] }
      stub(storage).read("feeds/hello-world") { {id: "feeds/hello-world", title: "Hello World"} }

      expect(feed_repository.list).to include(Feed.new(id: "feeds/hello-world", title: "Hello World"))
    end
  end
end
