module AudioFeedManager
  describe NewModelCreator do
    class SampleModel < Struct.new(:id, :title, :secret_token, :foo)
      include HashConstructor
    end

    let(:new_model_creator) { isolate(NewModelCreator) }
    let(:directory) { Pathname.new("/tmp/foo/feeds") }
    let(:prefix) { "feeds" }
    fake(:unique_id_generator, generate: "hello-world")
    fake(:secret_token_generator, generate: "secret-token")
    fake(:storage)

    it "sets the id for the added model" do
      stub(unique_id_generator).generate("Hello World!", directory) { "hello-world" }
      model = SampleModel.new(title: "Hello World!")

      new_model_creator.create(model, prefix: prefix, directory: directory)

      expect(model.id).to eq("feeds/hello-world")
    end

    it "stores the added model" do
      model = SampleModel.new(title: "Hello World!", foo: "hello there")

      new_model_creator.create(model, prefix: prefix, directory: directory)

      expect(storage).to have_received.store(
        "feeds/hello-world",
        id: "feeds/hello-world",
        title: "Hello World!",
        secret_token: "secret-token",
        foo: "hello there",
      )
    end

    it "assigns a secret token to the created model" do
      model = new_model_creator.create(SampleModel.new(title: "Hello World!"), prefix: prefix, directory: directory)

      expect(model.secret_token).to eq("secret-token")
    end

  end
end
