module AudioFeedManager
  describe RSSRepository do
    fake(:url_maker, feed_url: "http://example.com/feed.xml", audio_file_url: "http://example.com/audio/foo.mp3")
    let(:rss_files_directory) { Pathname.new("/tmp/my-project/rss") }

    before do
      FileUtils.rm_rf(rss_files_directory)
      FileUtils.mkdir_p(rss_files_directory)
    end

    it "stores an RSS feed under rss/:secret_token.xml" do
      feed = build_feed(id: "feeds/hello",
                        title: "My First Feed",
                        description: "some description",
                        secret_token: "abcdefgh")
      audio_file = build_audio_file(secret_token: "foobar",
                                    extension: ".mp3",
                                    title: "Some audio file",
                                    author: "Audio file author")
      rss_repository = isolate(RSSRepository)

      rss_repository.store(feed, [audio_file])

      feed_content = File.read("/tmp/my-project/rss/abcdefgh.xml")
      expect(feed_content).to include("<?xml")
      expect(feed_content).to include("My First Feed")
      expect(feed_content).to include("some description")
      expect(feed_content).not_to include("feeds/hello")
      expect(feed_content).to include("Some audio file")
      expect(feed_content).to include("Audio file author")
      expect(feed_content).to include("http://example.com/audio/foo.mp3")
    end
  end
end
