require 'net/http'

module AudioFeedManager
  describe S3Gateway, :slow do
    let(:config) { Config.new(s3_bucket: s3_config["bucket"],
                             s3_access_key: s3_config["access_key"],
                             s3_secret: s3_config["secret_key"],
                             s3_region: s3_config["region"]) }

    let(:s3_gateway) { isolate(S3Gateway) }

    it "syncs files to S3" do
      unique_key = "test/#{SecureRandom.hex}"
      file_name = :not_called

      s3_gateway.sync(unique_key, fixture_file("test.mp3")) { |f| file_name = f }

      expect(file_name).to eq(unique_key)
    end

    it "does not sync the same file twice" do
      unique_key = "test/#{SecureRandom.hex}"
      file_name = :not_called

      s3_gateway.sync(unique_key, fixture_file("test.mp3"))
      s3_gateway.sync(unique_key, fixture_file("test.mp3")) { |f| file_name = f }

      expect(file_name).to eq(:not_called)
    end

    it "syncs the same file twice if the contents change" do
      unique_key = "test/#{SecureRandom.hex}"
      file_name = :not_called

      s3_gateway.sync(unique_key, fixture_file("test.mp3"))
      s3_gateway.sync(unique_key, fixture_file("test.txt")) { |f| file_name = f }

      expect(file_name).to eq(unique_key)
    end

    it "makes the file publicly accessible" do
      unique_key = "test/#{SecureRandom.hex}"

      s3_gateway.sync(unique_key, fixture_file("test.txt"))

      url = URI.parse(s3_gateway.url(unique_key))
      content = File.read(fixture_file("test.txt"))
      expect(Net::HTTP.get(url)).to eq(content)
    end
  end
end
