module AudioFeedManager
  describe GetterSetterMethod do
    context "without a default value" do
      klass = Class.new do
        extend GetterSetterMethod

        get_set :foo
        get_set :bar
      end

      it "returns nil by default" do
        instance = klass.new

        expect(instance.foo).to be_nil
        expect(instance.bar).to be_nil
      end

      it "sets the value when value given" do
        instance = klass.new

        instance.foo "bar"

        expect(instance.foo).to eq("bar")
      end

      it "does not overwrite other values when setting one property" do
        instance = klass.new

        instance.foo "bar"

        expect(instance.bar).to be_nil
      end
    end

    context "with a default value" do
      klass = Class.new do
        extend GetterSetterMethod

        get_set(:foo) { bar }
        get_set :bar
        get_set(:baz) { "hello" }
      end

      it "returns the default value" do
        instance = klass.new

        expect(instance.baz).to eq("hello")
      end

      it "overwrites the value when value given" do
        instance = klass.new

        instance.baz "aaa"

        expect(instance.baz).to eq("aaa")
      end

      it "evaluates the default block lazily" do
        instance = klass.new

        instance.bar "aaa"

        expect(instance.foo).to eq("aaa")
      end

      it "caches the value once set" do
        instance = klass.new

        instance.bar "aaa"
        instance.foo
        instance.bar "bbb"

        expect(instance.foo).to eq("aaa")
      end
    end
  end
end
