require 'stringio'

describe "help commands" do
  let(:stdin) { StringIO.new }
  let(:stderr) { StringIO.new }

  it "prints help when no arguments given" do
    AudioFeedManager.run(
      argv: [],
      stdin: stdin,
      stderr: stderr,
    )

    expect(stderr.string).to include("Usage:")
    expect(stderr.string).to include("init")
  end

  it "prints help with the help command" do
    AudioFeedManager.run(
      argv: ["help"],
      stdin: stdin,
      stderr: stderr,
    )

    expect(stderr.string).to include("Usage:")
    expect(stderr.string).to include("init")
  end

  it "prints help with an unknown command" do
    AudioFeedManager.run(
      argv: ["asdfasdfa"],
      stdin: stdin,
      stderr: stderr,
      exit: ->(out) {}
    )

    expect(stderr.string).to include("Usage:")
    expect(stderr.string).to include("init")
  end

  it "prints help for specific commands" do
    AudioFeedManager.run(
      argv: ["help", "init"],
      stdin: stdin,
      stderr: stderr,
    )

    expect(stderr.string).to include("Usage:")
    expect(stderr.string).to include("init")
    expect(stderr.string).to include("<PROJECT_DIR>")
  end

  it "prints help for multi-word commands" do
    AudioFeedManager.run(
      argv: ["help", "feeds", "add"],
      stdin: stdin,
      stderr: stderr,
    )

    expect(stderr.string).to include("Usage:")
    expect(stderr.string).to include("feeds add")
    expect(stderr.string).to include("<TITLE>")
  end
end
